@@ -1,6 +1,6 @@
-#' Advanced plot function for component resolved CW-OSL curves
+#' @title Advanced plot function for component resolved CW-OSL curves
 #'
-#' This function is used for plotting CW-OSL curves and its signal components. It can handle data returned
+#' @description This function is used for plotting CW-OSL curves and its signal components. It can handle data returned
 #' by [fit_OSLcurve] or [decompose_OSLcurve]. Besides CW-OSL curves, pseudoLM-OSL curves and
 #' residual plots can also be plotted.
 #'
@@ -23,8 +23,12 @@
 #' The stimulation ramp duration is twice the CW-OSL duration.
 #' See Bos and Wallinga (2012) for a detailed explanation and discussion.
 #'
+#' This function was black-box tested prior release.
+#' These tests as well as code examples are available at:
+#' https://luminescence.de/OSLdecomposition/module_tests/Test_plot_OSLcurve.html
 #'
-#' @param curve [data.frame] or [matrix] or [RLum.Data.Curve-class] (*optional*):
+#'
+#' @param curve [data.frame] or [matrix] or [Luminescence::RLum.Data.Curve-class] (*optional*):
 #' CW-OSL curve x-Axis: `$time` or first column as measurement time (must have constant time intervals);
 #' y-Axis: `$signal` or second column as luminescence signal.
 #' Other columns will be plotted as component curves, in case no input object `components` is defined.
@@ -52,17 +56,22 @@
 #' @param show.initial [logical] (*with default*):
 #' Displays signal share at the first channel in the component table (if available).
 #'
-#' @param theme.set [ggplot2] object (*with default*):
+#' @param title [character] (*with default*):
+#' Plot title. Overwrites automatic titles but affects just the first (upper left)
+#' diagram in case of multi-plot display setting.
+#' Set `title = NULL` for auto-title and `title = ""` for no title.
+#'
+#' @param graph.colors [character] vector (*optional*):
+#' Color for the graphs/stacked areas are defined in the following order: 1. Measurement,
+#' 2. Model, 3. Component 1, 4. Component 2, etc. The color vector is allowed to
+#' be shorter than the needed colors. For missing colors, the default colors will be used
+#'
+#' @param theme.set [ggplot2::ggplot2-package] object (*with default*):
 #' Graphical theme of the output plot. This argument is forwarded to [ggplot2::theme_set].
 #' Recommended themes are `ggplot2::theme_minimal()`, `ggplot2::theme_classic()` and `ggplot2::theme_bw()`,
 #' see [ggplot2::theme_bw] or [here](https://ggplot2.tidyverse.org/reference/ggtheme.html) for
 #' a full list.
 #'
-#' @param title [character] (*with default*):
-#' Plot title. Overwrites automatic titles but affects just the first (upper left)
-#' graph in case of multi-graph display setting.
-#' Set `title = NULL` for auto-title and `title = ""` for no title.
-#'
 #' @param hide.plot [logical] (*with default*):
 #' If true, plot is not drawn but can still be saved as file or caught by `A <- plot_OSLcurve(...)`.
 #' If caught, the plot can be drawn manually for example by using [gridExtra::grid.arrange].
@@ -74,14 +83,15 @@
 #' and more, see [ggplot2::ggsave].
 #'
 #' @return
-#' An invisible [ggplot2::ggplot] object containing the diagram will returned. "Invisible" means, the no value
+#' An invisible [ggplot2::ggplot] object containing the diagram will be returned. "Invisible" means, the no value
 #' will be returned (e.g. no console printout) if the function is not assigned to a variable via `<-`.
-#' If the function is assigned, the returned object can be further manipulated by [ggplot2-package] methods
+#' If the function is assigned, the returned object can be further manipulated by [ggplot2::ggplot2-package] methods
 #' or manually drawn by various functions like for example [gridExtra::grid.arrange].
 #'
-#' @section Last update:
+#' @section Last updates:
 #'
-#' 2021-03-29, DM: Hidden output objects are now [ggplot2] objects if the plot is not a composite diagram
+#' 2025-08-29, DM: Function is now a wrapper of [plot_MultiExponential] which makes it more stable and universal.
+#' 2025-08-29, DM: Changed from component graphs to colored areas. Changed also default colors..
 #'
 #' @author
 #' Dirk Mittelstraß, \email{dirk.mittelstrass@@luminescence.de}
@@ -91,7 +101,7 @@
 #' Mittelstraß, D., Schmidt, C., Beyer, J., Heitmann, J. and Straessner, A.:
 #' R package OSLdecomposition: Automated identification and separation of quartz CW-OSL signal components, *in preparation*.
 #'
-#' @seealso [fit_OSLcurve], [RLum.OSL_decomposition, [RLum.OSL_global_fitting], [simulate_OSLcomponents]
+#' @seealso [fit_OSLcurve], [RLum.OSL_decomposition], [RLum.OSL_global_fitting], [simulate_OSLcomponents]
 #'
 #' @references
 #' Bos, A. J. J. and Wallinga, J., 2012. How to visualize quartz OSL signal components,
@@ -119,69 +129,38 @@
 plot_OSLcurve <- function(curve = NULL,
                           components = NULL,
                           display = "detailed",
-                          show.legend = TRUE,
+                          show.legend = FALSE,
                           show.intervals = FALSE,
                           show.crosssec = FALSE,
                           show.initial = FALSE,
-                          theme.set = ggplot2::theme_classic(),
                           title = NULL,
+                          graph.colors = NULL,
+                          theme.set = ggplot2::theme_classic(),
                           hide.plot = FALSE,
                           filename = NULL){
 
-
-# Changelog:
-# * 2019-03-06, DM: First reasonable version
-# * 2019-04-03, DM: Rebuild whole function
-# * 2019-10-02, DM: Added background component support and some little tweaks
-# * 2020-04-22, DM: Enabled hidden output to draw later
-# * 2020-06-19, DM: Added pseudoLM-OSL diagrams
-# * 2020-08-04, DM: Added subtitles and RSS info
-# * 2020-09-02, DM: Added graphic saving with [ggplot2::ggsave]
-# * 2020-11-03, DM: Refactored code; Changed parameter `display` choices and added parameters `theme.set` and `show.legend`
-# * 2020-11-11, DM: Improved parameter table
-# * 2020-11-16, DM: Added parameter `show.crosssec` and `show.initial`
-# * 2020-11-19, DM: RLum.Data.Curves can now be displayed without 'components' if RLum.OSL_decomposition was already performed at data set
-# * 2021-03-29, DM: Hidden output objects are now [ggplot2] objects if the plot is not a composite diagram
-#
-# ToDo:
-# * When drawing components without curve, skip residual curve
-# * Display fitting formula
-# * Add argument ggsave.control() to give direct control about image saving
-# * Add lambda error in the component table
-# * Draw bin intervals directly into the diagram (optionally)
-
-
-  # necessary libraries: gridExtra, ggplot2, ggpubr, scales
-
-  # Hidden parameters
-  zoom <- 1
-
-  # Solve a devtools::check problem were it complains about ggplot2 syntax ("no visible binding for global variable")
-  signal <- graph <- residual <- NULL
-
-  ###################### PLOT DESIGN ######################
-
-  # Set color and line themes
-  ggplot2::theme_set(theme.set)
-  graph.colors <- c("darkgrey", "black","red3","green3","royalblue3","darkorchid","gold","brown","pink")
-  graph.sizes <- c(1, 1, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5)
-  graph.shapes <-  c(16, 32, 32, 32, 32, 32, 32, 32, 32)
-  graph.lines <- c("blank","solid","solid","solid","solid","solid","solid","solid","solid")
-
-  # Reduce font size
-  text_format <- ggplot2::theme(axis.title = ggplot2::element_text(size = 8),
-                       plot.subtitle = ggplot2::element_text(size = 9, face = "bold"),
-                       legend.position = c(1, 1), legend.justification = c("right", "top"),
-                       legend.title = ggplot2::element_blank(),
-                       legend.text = ggplot2::element_text(size = 8))
-
-  # LOG-Scales only: set breaks
-  breaks <- 10^(-10:10)
-  minor_breaks <- rep(1:9, 21)*(10^rep(-10:10, each=9))
-
-  guide <- "none"
-  if (show.legend) guide <- "legend"
-
+  # Changelog:
+  # * 2019-03-06, DM: First reasonable version
+  # * 2019-04-03, DM: Rebuild whole function
+  # * 2019-10-02, DM: Added background component support and some little tweaks
+  # * 2020-04-22, DM: Enabled hidden output to draw later
+  # * 2020-06-19, DM: Added pseudoLM-OSL diagrams
+  # * 2020-08-04, DM: Added subtitles and RSS info
+  # * 2020-09-02, DM: Added graphic saving with [ggplot2::ggsave]
+  # * 2020-11-03, DM: Refactored code; Changed parameter `display` choices and added parameters `theme.set` and `show.legend`
+  # * 2020-11-11, DM: Improved parameter table
+  # * 2020-11-16, DM: Added parameter `show.crosssec` and `show.initial`
+  # * 2020-11-19, DM: RLum.Data.Curves can now be displayed without 'components' if RLum.OSL_decomposition was already performed at data set
+  # * 2021-03-29, DM: Hidden output objects are now [ggplot2] objects if the plot is not a composite diagram
+  # * 2025-08-29, DM: Function is now a wrapper of [plot_MultiExponential] which makes it more stable and universal.
+  # * 2025-08-29, DM: Changed from component graphs to colored areas. Changed also default colors..
+  #
+  # ToDo:
+  # * When drawing components without curve, skip residual curve
+  # * Display fitting formula
+  # * Add argument ggsave.control() to give direct control about image saving
+  # * Add lambda error in the component table
+  # * Draw bin intervals directly into the diagram (optionally)
 
   ###################### INPUT DATA  ######################
 
@@ -213,63 +192,70 @@ plot_OSLcurve <- function(curve = NULL,
           components <- curve@info$COMPONENTS
 
         }else{
-
           # switch to simple plot
           display <- "raw"}}
 
       # now transform the RLum object into a simple table. There is no need to keep all the extra info
       curve <- as.data.frame(Luminescence::get_RLum(curve))
-
-
     }
 
     if (!("time" %in% colnames(curve)) |
         !("signal" %in% colnames(curve))) {
 
-      curve <- data.frame(time = curve[,1],
-                          signal = curve[,2])}}
+      curve <- data.frame(time = curve[,1], signal = curve[,2])}
+  }
 
   time <- curve$time
-  channel.width <- time[2] - time[1]
-
-  # Set x-axis zoom
-  X_limits <- c(0, max(time)*zoom)
-
-  # Transform data into factor-based long data set
-  data <- data.frame(time = time, signal = curve$signal, graph = factor("meas"))
 
   # if a component table is given, add or overwrite the component signal columns in the curve data.frame
-  if (!is.null(components)) {
-    #|| !("residual" %in% colnames(curve))
-    curve <- simulate_OSLcomponents(components, curve, simulate.curve = FALSE)}
+  if (!is.null(components))
+    curve <- simulate_OSLcomponents(components, curve, simulate.curve = FALSE)
 
   # Does 'curve' now contain component information?
   if (length(curve[1,]) < 3) {
 
     warning("No component curve given neither in 'components' nor in 'curve'. Set 'display' = 'raw'")
     display <- "raw"
+  }
 
-  } else if (display != "raw"){
+  ###################### PLOT DESIGN ######################
 
-    # set the columns which shall be displayed
-    X <- c(1:length(curve[1,]))
-    X <- X[colnames(curve) != "residual"]
-    X <- X[3:length(X)]
+  # Set color and line themes
+  ggplot2::theme_set(theme.set)
 
-    # set legend text
-    graph.labels <- c("", colnames(curve)[X])
-    graph.labels[1] <- "Measurement"
-    graph.labels[2] <- "Model"
+  guide <- "none"
+  if (show.legend) guide <- "right"
 
-    # rearrange data to work in ggplot-function
-    for (i in X) {
+  # Old colors of OSLdecomposition 1.0.0
+  # graph.colors <- c("darkgrey", "black","red3","green3","royalblue3","darkorchid","gold","brown","pink")
 
-      data.append <- data.frame(time = time, signal = curve[,i], graph = colnames(curve)[i])
-      data <- rbind(data, data.append)}}
+  # New colors
+  graph_colors <- c("grey30", "darkblue", "skyblue2","orchid","cyan2","orange","red2","pink3","brown2")
+  if (length(graph.colors) > 0)
+    graph_colors[1:length(graph.colors)] <- graph.colors
 
-  # LOG-Scales only: set y-axis minimum
-  log_limits <- c(1, max(data$signal))
-  if (min(curve$signal) > 0) log_limits[1] <- 10^floor(log10(min(curve$signal)))
+  # The colors are NOT assigned to the components iterativly
+  # see plot_MultiExponential for the rules. However, we have to resort
+  # the colors to be in line with plot_MultiExponential
+  if(display != "raw" && !is.null(components) && nrow(components) > 0){
+
+    component_colors <- rep("black", nrow(components))
+    col_i <- 3
+    for(i in nrow(components):1){
+
+      if (components$n[i] > 0) {
+        component_colors[i] <- graph_colors[col_i]
+        col_i <- col_i + 1
+      }
+    }
+    for(i in nrow(components):1){
+
+      if (components$n[i] < 0) {
+        component_colors[i] <- graph_colors[col_i]
+        col_i <- col_i + 1
+      }
+    }
+  }
 
 
 
@@ -277,120 +263,76 @@ plot_OSLcurve <- function(curve = NULL,
 
   if ((display == "detailed") | (display == "lin") | (display == "compare_lin")) {
 
-    if (is.null(title)) {
+    if (is.null(title)) title <- "CW-OSL"
 
-      subtitle <- "CW-OSL"
-     # if (display == "lin") subtitle <- NULL
+    p.lin <- plot_MultiExponential(curve, components,
+                                   main = title,
+                                   xlab = "Time (s)", ylab = "Signal (cts)",
+                                   theme.set = theme.set,
+                                   font.size = 8,
+                                   legend.position = guide,
+                                   hide.plot = TRUE)
 
-    }else{
+    # Deactivate legend for all following plots
+    guide <- "none"
+    title <- NULL
 
-      subtitle <- title
-      title <- NULL}
-
-
-    p.lin <- ggplot2::ggplot(data, ggplot2::aes(x = time, y = signal, colour = graph,
-                                                size = graph, shape = graph, linetype = graph)) +
-      ggplot2::geom_point(na.rm = TRUE) + ggplot2::geom_line(na.rm = TRUE) +
-      ggplot2::scale_y_continuous(limits = c(0, max(curve$signal) + 1), labels = scales::label_number_auto()) +
-      ggplot2::scale_x_continuous(limits = X_limits, labels = scales::label_number_auto()) +
-      ggplot2::scale_colour_manual(values = graph.colors, labels = graph.labels, guide = guide) +
-      ggplot2::scale_size_manual(values = graph.sizes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_shape_manual(values = graph.shapes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_linetype_manual(values = graph.lines, labels = graph.labels, guide = guide) +
-      ggplot2::labs(subtitle = subtitle, x = "Time (s)", y = "Signal (cts)") +
-      text_format
-
-    guide <- "none"}
+  }
 
   ######################## LOG PLOT #########################################################
 
   if ((display == "log") | (display == "compare_log")) {
 
-    if (is.null(title)) {
+    if (is.null(title)) title <- "CW-OSL (logarithmic scale)"
 
-      subtitle <- "CW-OSL (logarithmic scale)"
-      #if (display == "log") subtitle <- NULL
-
-    }else{
-
-      subtitle <- title
-      title <- NULL}
-
-    p.log <- ggplot2::ggplot(data, ggplot2::aes(x=time, y=signal, colour=graph, size=graph, shape=graph, linetype=graph)) +
-      ggplot2::geom_point(na.rm = TRUE) + ggplot2::geom_line(na.rm = TRUE) +
-      ggplot2::scale_y_log10(limits = log_limits, #position = "right",
-                             breaks = breaks, minor_breaks = minor_breaks,
-                             labels = scales::label_number_auto()) +
-      ggplot2::scale_x_continuous(limits = X_limits, labels = scales::label_number_auto()) +
-      ggplot2::scale_colour_manual(values = graph.colors, labels = graph.labels, guide = guide) +
-      ggplot2::scale_size_manual(values = graph.sizes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_shape_manual(values = graph.shapes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_linetype_manual(values = graph.lines, labels = graph.labels, guide = guide) +
-      ggplot2::labs(subtitle = subtitle, x = "Time (s)", y = "Signal (cts)") +
-      text_format}
+    p.log  <- plot_MultiExponential(curve, components,
+                                    main = title,
+                                    theme.set = theme.set,
+                                    ylog = TRUE,
+                                    font.size = 8,
+                                    legend.position = guide,
+                                    xlab = "Time (s)", ylab = "Signal (cts)",
+                                    hide.plot = TRUE)
+    guide <- "none"
+    title <- NULL
+  }
 
   ######################## LOG-LOG PLOT #########################################################
 
   if (display == "loglog") {
 
-    if (is.null(title)) {
+    if (is.null(title)) title <- "CW-OSL (double logarithmic scale)"
 
-      subtitle <- "CW-OSL (double logarithmic scale)"
-
-    }else{
-
-      subtitle <- title
-      title <- NULL}
-
-    p.loglog <- ggplot2::ggplot(data, ggplot2::aes(x=time, y=signal, colour=graph, size=graph, shape=graph, linetype=graph)) +
-      ggplot2::geom_point(na.rm = TRUE) + ggplot2::geom_line(na.rm = TRUE) +
-      ggplot2::scale_y_log10(limits = log_limits,
-                             breaks = breaks, minor_breaks = minor_breaks,
-                             labels = scales::label_number_auto()) +
-      ggplot2::scale_x_log10(limits = c(channel.width, max(time)),
-                             breaks = breaks, minor_breaks = minor_breaks,
-                             labels = scales::label_number_auto()) +
-      ggplot2::scale_colour_manual(values = graph.colors, labels = graph.labels, guide = guide) +
-      ggplot2::scale_size_manual(values = graph.sizes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_shape_manual(values = graph.shapes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_linetype_manual(values = graph.lines, labels = graph.labels, guide = guide) +
-      ggplot2::labs(subtitle = subtitle, x = "Time (s)", y = "Signal (cts)") +
-      text_format}
+    p.loglog  <- plot_MultiExponential(curve, components,
+                                       main = title,
+                                       theme.set = theme.set,
+                                       ylog = TRUE, xlog = TRUE,
+                                       font.size = 8,
+                                       legend.position = guide,
+                                       xlab = "Time (s)", ylab = "Signal (cts)",
+                                       hide.plot = TRUE)
+    guide <- "none"
+    title <- NULL
+  }
 
 
   ######################## pseudoLM PLOT #########################################################
 
   if ((display == "detailed") | (display == "LM")) {
 
-    if (is.null(title)) {
+    if (is.null(title)) title <- "pseudoLM-OSL"
 
-      subtitle <- "pseudoLM-OSL"
-      #if (display == "LM") subtitle <- NULL
-
-    }else{
-
-      subtitle <- title
-      title <- NULL}
-
-    # transform data
-    P = 2*max(time)
-    LMdata <- data
-    LMdata$signal <- LMdata$signal * sqrt(2 * LMdata$time / P)
-    LMdata$time <- sqrt(2 * P * LMdata$time)
-
-
-    p.LM <- ggplot2::ggplot(LMdata, ggplot2::aes(x=time, y=signal, colour=graph, size=graph, shape=graph, linetype=graph)) +
-      ggplot2::geom_point(na.rm = TRUE) + ggplot2::geom_line(na.rm = TRUE) +
-      ggplot2::scale_y_continuous(limits = c(0, max(LMdata$signal) + 1),
-                                  labels = scales::label_number_auto()) +
-      ggplot2::scale_x_continuous(limits = c(0, X_limits[2]*2),
-                                  labels = scales::label_number_auto()) +
-      ggplot2::scale_colour_manual(values = graph.colors, labels = graph.labels, guide = guide) +
-      ggplot2::scale_size_manual(values = graph.sizes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_shape_manual(values = graph.shapes, labels = graph.labels, guide = guide) +
-      ggplot2::scale_linetype_manual(values = graph.lines, labels = graph.labels, guide = guide) +
-      ggplot2::labs(subtitle = subtitle, x = "Ramping time (s)", y ="Signal (cts)") +
-      text_format}
+    p.LM  <- plot_MultiExponential(curve, components,
+                                   main = title,
+                                   theme.set = theme.set,
+                                   linear.modulation = TRUE,
+                                   xlab = "Time (s)", ylab = "Signal (cts)",
+                                   font.size = 8,
+                                   legend.position = guide,
+                                   hide.plot = TRUE)
+    guide <- "none"
+    title <- NULL
+  }
 
 
   ######################## RESIDUAL #########################################################
@@ -399,27 +341,33 @@ plot_OSLcurve <- function(curve = NULL,
       (display == "compare_log") | (display == "res")) {
 
     res <- curve$residual
+    res_curve <- data.frame(time = curve$time, signal = res)
 
-    if (is.null(title)) {
+    if (is.null(title)) title <- "Residual"
+    # IMPORTANT: Deactivated RSS display for the moment as there is a mismatch
+    #            between RSS here and those returned by fit_OSLcurve()
+    # if (is.null(title))
+    #   title <- paste0("Residual (RSS = ", prettyNum(sum(res^2, na.rm = TRUE), digits = 1), ")")
 
-      res_text <- paste0("Residual (RSS = ", prettyNum(sum(res^2, na.rm = TRUE), digits = 1), ")")
-
-    }else{
-
-      res_text <- title
-      title <- NULL}
-
-
-    # set y-axis
-    res.max <- ceiling(abs(max(res))) + 1
-    if (abs(min(res)) > res.max) res.max <- ceiling(abs(min(res))) + 1
+    # Plot residual curve
+    p.res  <- plot_MultiExponential(res_curve,
+                                    main = title,
+                                    theme.set = theme.set,
+                                    xlab = "Time (s)", ylab = "Signal (cts)",
+                                    font.size = 8,
+                                    legend.position = guide,
+                                    hide.plot = TRUE)
 
     # if the integration intervals are given, draw them into the residual curve
-    res.intervals <- list(NULL)
     if (("t.start" %in% colnames(components))
-        & (zoom == 1)
         & show.intervals) {
 
+      res.intervals <- list(NULL)
+
+      # set y-axis
+      res.max <- ceiling(abs(max(res))) + 1
+      if (abs(min(res)) > res.max) res.max <- ceiling(abs(min(res))) + 1
+
       for (i in c(1:nrow(components))) {
 
         res.intervals[[i*2 - 1]] <- ggplot2::annotate("segment",
@@ -437,32 +385,16 @@ plot_OSLcurve <- function(curve = NULL,
       if (t.times[1] == 0) t.labels <- c("", formatC(components$t.end))
       if (t.labels[length(t.labels)] == time[length(time)]) t.labels[length(t.labels)] <- ""
 
-      scale.intervals <- ggplot2::scale_x_continuous(breaks = t.times, limits = X_limits, labels = t.labels)
-
-    } else {
-
-      scale.intervals <- ggplot2::scale_x_continuous(limits = X_limits,
-                                                     labels = scales::label_number_auto())}
-
-
-    # Plot residual curve
-    p.res <- ggplot2::ggplot(curve, ggplot2::aes(x=time, y=residual)) +
-      ggplot2::geom_point(size = 1, shape =  16, color = "darkgrey", na.rm = TRUE) +
-      ggplot2::scale_y_continuous(limits = c(- res.max, res.max),
-                                  labels = scales::label_number_auto()) +
-      ggplot2::labs(subtitle = res_text, x = "Time (s)", y ="Signal (cts)") +
-      ggplot2::annotate("segment", x = 0, xend = max(curve$time), y = 0, yend = 0, colour = "black", size = 1) +
-      text_format +
-      scale.intervals +
-      res.intervals}
-
+      p.res <- p.res + res.intervals +
+        ggplot2::scale_x_continuous(breaks = t.times, limits = c(0, max(time)), labels = t.labels)
+    }
+  }
 
   ######################## TABLE #########################################################
 
   if ((display == "detailed") | (display == "compare_lin") |
       (display == "compare_log") | (display == "tab")) {
 
-
     if (!is.null(components) ) {
 
       # Table styles can be found at:
@@ -489,8 +421,6 @@ plot_OSLcurve <- function(curve = NULL,
                             n = prettyNum(round(components$n)))
       p.colnames <- c(p.colnames, expression(italic(n)))
 
-      #p.colnames <- c(p.colnames, paste0(expression(italic(n)), " \u00b1 ", expression(italic(sigma[n]))))
-
       if ("n.error" %in% colnames(components)) {
         p.table$n <- paste0(p.table$n, " \u00b1 ", prettyNum(round(components$n.error)))}
 
@@ -519,12 +449,13 @@ plot_OSLcurve <- function(curve = NULL,
 
       # assign graph colors to component names
       for (z in 1:nrow(p.table)) {
-        p.tab <- ggpubr::table_cell_bg(p.tab, row = 1 + z, column = 1, fill = graph.colors[z + 2],
+        p.tab <- ggpubr::table_cell_bg(p.tab, row = 1 + z, column = 1, fill = component_colors[z],
                                        color = "white", linewidth = 5)}
 
     } else {
 
       # if no component table is given, draw blank image
+      p.table <- data.frame(NULL)
       p.tab <- ggplot2::ggplot() + ggplot2::geom_blank()}}
 
 
@@ -533,12 +464,14 @@ plot_OSLcurve <- function(curve = NULL,
   if (display == "raw") {
 
     # Create plot without components
-    p.raw <- ggplot2::ggplot(curve, ggplot2::aes(x=time, y=signal)) +
-      ggplot2::geom_line(na.rm = TRUE, color = "black") +
-      ggplot2::scale_y_continuous(limits = c(0, 1.1 * max(curve$signal))) +
-      ggplot2::scale_x_continuous(limits = X_limits) +
-      ggplot2::ylab("Signal (cts)") + ggplot2::xlab("Time (s)") +
-      text_format}
+    p.raw <- plot_MultiExponential(curve,
+                                   main = title,
+                                   theme.set = theme.set,
+                                   xlab = "Time (s)", ylab = "Signal (cts)",
+                                   font.size = 8,
+                                   legend.position = guide,
+                                   hide.plot = TRUE)
+  }
 
 
   #########################################################################################
